@@ -4,9 +4,9 @@ setGeneric("emd", function(x, y, ...) {
 setMethod("emd", signature = c(x = "RasterLayer", y = "RasterLayer"),
           function(x, y, ...)
           {
-            if (class(x) == "RasterLayer")
+           # if (class(x) == "RasterLayer")
               x <- (rasterToPoints(x, spatial = T))
-            if (class(y) == "RasterLayer")
+          #  if (class(y) == "RasterLayer")
               y <- (rasterToPoints(y, spatial = T))
             emd(x, y, ...)
           })
@@ -30,17 +30,17 @@ setMethod("emd", signature = c(x = "SpatialPoints", y = "SpatialPoints"),
               yv <- rep(1, length(y)) / length(y)
             }
             if (!isTRUE(all.equal(sum(xv), sum(yv))))
-              warning(paste("rasters dont have equal mass, delta:", sum(xv) -
+              warning(paste("datasets dont have equal mass, delta:", sum(xv) -
                               sum(yv)))
             if (!isTRUE(all.equal(sum(xv), 1)))
-              warning("raster does not represent probability surface")
+              warning("data does not represent probability surface")
             res <- 1
             fun <- "emdR"
             if (!is.null(threshold))
             {
               if (!isTRUE(all.equal(coordinates(y), coordinates(x), check.attributes =
                                     F))) {
-                stop("raster definitions are unequal this does not work with the fast emd")
+                stop("spatial data locations are unequal between datasets, this does not work with the fast emd")
               }
               fun <- "emdR_gd"
               s <- !(xv == 0 & yv == 0)
@@ -56,8 +56,8 @@ setMethod("emd", signature = c(x = "SpatialPoints", y = "SpatialPoints"),
             }
             a <- .C(
               fun,
-              Pn = as.integer(nrow(x)),
-              Qn = as.integer(nrow(y)),
+              Pn = as.integer(length(x)),
+              Qn = as.integer(length(y)),
               Px = as.double(coordinates(x)[, 1]),
               Py = as.double(coordinates(x)[, 2]),
               Pw = as.double(xv),
@@ -77,9 +77,11 @@ setMethod("emd", signature = c(x = "RasterStackBrick", y = "missing"),
           {
             comb <- combn(n <- names(x), 2)
             m <- matrix(0, length(n), length(n), dimnames = list(n, n))
+            xx<-lapply(unstack(x), rasterToPoints, spatial=T)
+            names(xx)<-names(x)
             for (i in 1:ncol(comb))
             {
-              r <- emd(x[[comb[1, i]]], x[[comb[2, i]]], ...)
+              r <- emd(xx[[comb[1, i]]], xx[[comb[2, i]]], ...)
               m[comb[1, i], comb[2, i]] <- r
               m[comb[2, i], comb[1, i]] <- r
               
@@ -93,9 +95,13 @@ setMethod("emd", signature = c(x = "RasterStackBrick", y = "RasterStackBrick"),
             comb <- expand.grid(nx <- names(x), ny <- names(y))
             m <-
               matrix(0, length(nx), length(ny), dimnames = list(nx, ny))
+            xx<-lapply(unstack(x), rasterToPoints, spatial=T)
+            names(xx)<-names(x)
+            yy<-lapply(unstack(y), rasterToPoints, spatial=T)
+            names(yy)<-names(y)
             for (i in 1:nrow(comb))
             {
-              r <- emd(x[[comb[i, 1]]], y[[comb[i, 2]]], ...)
+              r <- emd(xx[[comb[i, 1]]], yy[[comb[i, 2]]], ...)
               m[comb[i, 1], comb[i, 2]] <- r
             }
             return((m))
